@@ -9,11 +9,11 @@ REPLY_TEMPLATE = "[Let me google that for you](https://lmgtfy.com/?q={})"
 
 def main():
     reddit = praw.Reddit(
-        user_agent="LMGTFY (by u/USERNAME)",
         client_id="CLIENT_ID",
         client_secret="CLIENT_SECRET",
-        username="USERNAME",
         password="PASSWORD",
+        user_agent="LMGTFY (by u/USERNAME)",
+        username="USERNAME",
     )
 
     subreddit = reddit.subreddit("AskReddit")
@@ -32,7 +32,7 @@ def process_submission(submission):
             url_title = quote_plus(submission.title)
             reply_text = REPLY_TEMPLATE.format(url_title)
             print(f"Replying to: {submission.title}")
-            submission.reply(reply_text)
+            submission.reply(body=reply_text)
             # A reply has been made so do not attempt to match other phrases.
             break
 
