@@ -47,9 +47,7 @@ class TestEmoji(IntegrationTest):
         subreddit = self.reddit.subreddit(pytest.placeholders.test_subreddit)
         with self.use_cassette():
             subreddit.emoji["test_png"].update(
-                mod_flair_only=False,
-                post_flair_allowed=True,
-                user_flair_allowed=True,
+                mod_flair_only=False, post_flair_allowed=True, user_flair_allowed=True
             )
 
     @mock.patch("time.sleep", return_value=None)
@@ -79,8 +77,8 @@ class TestSubredditEmoji(IntegrationTest):
         with self.use_cassette():
             for extension in ["jpg", "png"]:
                 emoji = subreddit.emoji.add(
-                    f"test_{extension}",
-                    f"tests/integration/files/test.{extension}",
+                    name=f"test_{extension}",
+                    image_path=f"tests/integration/files/test.{extension}",
                 )
                 assert isinstance(emoji, Emoji)
 
@@ -91,8 +89,8 @@ class TestSubredditEmoji(IntegrationTest):
         with self.use_cassette():
             for extension in ["jpg", "png"]:
                 emoji = subreddit.emoji.add(
-                    f"test_{extension}",
-                    f"tests/integration/files/test.{extension}",
+                    name=f"test_{extension}",
+                    image_path=f"tests/integration/files/test.{extension}",
                     mod_flair_only=True,
                     post_flair_allowed=True,
                     user_flair_allowed=False,
