@@ -1,4 +1,3 @@
-import sys
 from datetime import datetime
 from unittest import mock
 
@@ -40,22 +39,12 @@ class TestModmailConversation(IntegrationTest):
         self.reddit.read_only = False
         conversation = self.reddit.subreddit("all").modmail("g46rw")
         with self.recorder.use_cassette("TestModmailConversation.test_mute_duration"):
-            conversation.mute(7)
+            conversation.mute(num_days=7)
             conversation = self.reddit.subreddit("all").modmail("g46rw")
             assert conversation.user.mute_status["isMuted"]
-            if sys.version_info >= (3, 7, 0):
-                diff = datetime.fromisoformat(
-                    conversation.user.mute_status["endDate"]
-                ) - datetime.fromisoformat(conversation.mod_actions[-1].date)
-            else:
-                end_date = "".join(
-                    conversation.user.mute_status["endDate"].rsplit(":", 1)
-                )
-                start_date = "".join(conversation.mod_actions[-1].date.rsplit(":", 1))
-                date_format = "%Y-%m-%dT%H:%M:%S.%f%z"
-                diff = datetime.strptime(end_date, date_format) - datetime.strptime(
-                    start_date, date_format
-                )
+            diff = datetime.fromisoformat(
+                conversation.user.mute_status["endDate"]
+            ) - datetime.fromisoformat(conversation.mod_actions[-1].date)
             assert diff.days == 6  # 6 here because it is not 7 whole days
 
     @mock.patch("time.sleep", return_value=None)
@@ -77,7 +66,7 @@ class TestModmailConversation(IntegrationTest):
         self.reddit.read_only = False
         conversation = self.reddit.subreddit("all").modmail("ik72")
         with self.use_cassette():
-            reply = conversation.reply("A message")
+            reply = conversation.reply(body="A message")
         assert isinstance(reply, ModmailMessage)
 
     @mock.patch("time.sleep", return_value=None)
