@@ -61,7 +61,7 @@ class TestRedditor(IntegrationTest):
         self.reddit.read_only = False
         with self.use_cassette():
             redditor = self.reddit.redditor("subreddit_stats")
-            redditor.message("PRAW test", "This is a test from PRAW")
+            redditor.message(subject="PRAW test", message="This is a test from PRAW")
 
     @mock.patch("time.sleep", return_value=None)
     def test_message_from_subreddit(self, _):
@@ -69,8 +69,8 @@ class TestRedditor(IntegrationTest):
         with self.use_cassette():
             redditor = self.reddit.redditor("subreddit_stats")
             redditor.message(
-                "PRAW test",
-                "This is a test from PRAW",
+                subject="PRAW test",
+                message="This is a test from PRAW",
                 from_subreddit=pytest.placeholders.test_subreddit,
             )
 
@@ -136,6 +136,15 @@ class TestRedditor(IntegrationTest):
             redditor = self.reddit.user.friends()[0]
             assert redditor.unfriend() is None
 
+    def test_notes__subreddits(self):
+        self.reddit.read_only = False
+        with self.use_cassette():
+            redditor = self.reddit.redditor("Watchful1")
+            notes = list(redditor.notes.subreddits("subtestbot1", "subtestbot2"))
+            assert len(notes) == 2
+            assert notes[0].user == redditor
+            assert notes[1] is None
+
 
 class TestRedditorListings(IntegrationTest):
     def test_comments__controversial(self):
