@@ -1,9 +1,11 @@
 """Test praw.reddit."""
+from base64 import urlsafe_b64encode
 from unittest import mock
 
 import pytest
 from prawcore.exceptions import BadRequest
 
+from praw.exceptions import RedditAPIException
 from praw.models import LiveThread
 from praw.models.reddit.base import RedditBase
 from praw.models.reddit.submission import Submission
@@ -13,6 +15,41 @@ from . import IntegrationTest
 
 
 class TestReddit(IntegrationTest):
+    def test_bad_request_without_json_text_plain_response(self):
+        with open("tests/integration/files/too_large.jpg", "rb") as fp:
+            junk = urlsafe_b64encode(fp.read()).decode()
+        with self.use_cassette(
+            placeholders=self.recorder.configure().default_cassette_options[
+                "placeholders"
+            ]
+            + [{"placeholder": "<CONTENT>", "replace": junk}]
+        ):
+            with pytest.raises(RedditAPIException) as excinfo:
+                self.reddit.request(
+                    method="GET",
+                    path=f"/api/morechildren?link_id=t3_n7r3uz&children={junk}",
+                )
+            assert str(excinfo.value) == "Bad Request"
+
+    def test_bad_request_without_json_text_html_response(self):
+        with open("tests/integration/files/comment_ids.txt") as fp:
+            ids = fp.read()[:8000]
+        with self.use_cassette(
+            placeholders=self.recorder.configure().default_cassette_options[
+                "placeholders"
+            ]
+            + [{"placeholder": "<COMMENT_IDS>", "replace": ids}]
+        ):
+            with pytest.raises(RedditAPIException) as excinfo:
+                self.reddit.request(
+                    method="GET",
+                    path=f"/api/morechildren?link_id=t3_n7r3uz&children={ids}",
+                )
+            assert (
+                str(excinfo.value)
+                == "<html><body><h1>400 Bad request</h1>\nYour browser sent an invalid request.\n</body></html>\n"
+            )
+
     def test_bare_badrequest(self):
         data = {
             "sr": "AskReddit",
@@ -34,7 +71,7 @@ class TestReddit(IntegrationTest):
             for base in bases:
                 items.append(f"{base}{i:02d}")
 
-        item_generator = self.reddit.info(items)
+        item_generator = self.reddit.info(fullnames=items)
         with self.use_cassette():
             results = list(item_generator)
         assert len(results) > 100
@@ -132,6 +169,32 @@ class TestReddit(IntegrationTest):
         with self.use_cassette():
             assert self.reddit.live.now() is None
 
+    def test_notes__call__(self):
+        self.reddit.read_only = False
+        with self.use_cassette():
+            notes = list(
+                self.reddit.notes(
+                    pairs=[
+                        (self.reddit.subreddit("SubTestBot1"), "Watchful1"),
+                        ("SubTestBot1", self.reddit.redditor("watchful12")),
+                        ("SubTestBot1", "spez"),
+                    ],
+                    things=[self.reddit.submission("jlbw48")],
+                )
+            )
+            assert len(notes) == 4
+            assert notes[0].user.name.lower() == "watchful1"
+            assert notes[1].user.name.lower() == "watchful12"
+            assert notes[2] is None
+
+    def test_notes__things(self):
+        self.reddit.read_only = False
+        with self.use_cassette():
+            thing = self.reddit.submission("tpbemz")
+            notes = list(self.reddit.notes.things(thing))
+            assert len(notes) == 10
+            assert notes[0].user == thing.author
+
     def test_random_subreddit(self):
         names = set()
         with self.use_cassette():
@@ -149,6 +212,26 @@ class TestReddit(IntegrationTest):
         with self.use_cassette():
             assert self.reddit.subreddit("random").display_name != "random"
 
+    def test_username_available__available(self):
+        fake_user = "prawtestuserabcd1234"
+        with self.use_cassette(
+            placeholders=self.recorder.configure().default_cassette_options[
+                "placeholders"
+            ]
+            + [{"placeholder": "<AVAILABLE_NAME>", "replace": fake_user}]
+        ):
+            assert self.reddit.username_available(fake_user)
+
+    def test_username_available__unavailable(self):
+        with self.use_cassette():
+            assert not self.reddit.username_available("bboe")
+
+    def test_username_available_exception(self):
+        with self.use_cassette():
+            with pytest.raises(RedditAPIException) as exc:
+                self.reddit.username_available("a")
+            assert str(exc.value) == "BAD_USERNAME: 'invalid user name' on field 'user'"
+
 
 class TestDomainListing(IntegrationTest):
     def test_controversial(self):
